@@ -3,7 +3,7 @@ use warnings;
 
 package Code::Statistics::Metric::ccomp;
 BEGIN {
-  $Code::Statistics::Metric::ccomp::VERSION = '1.102390';
+  $Code::Statistics::Metric::ccomp::VERSION = '1.102520';
 }
 
 # ABSTRACT: measures the cyclomatic complexity of a target
@@ -11,21 +11,13 @@ BEGIN {
 use Moose;
 extends 'Code::Statistics::Metric';
 
-use Perl::Metrics::Simple::Analysis::File;
+use Perl::Critic::Utils::McCabe 'calculate_mccabe_of_sub';
 
 
 sub measure {
     my ( $class, $target ) = @_;
 
-    # not sure whether this is the right way to go, but sub-classing looks like
-    # decidedly more work, to do the same exact thing
-    my $s = bless {}, 'Perl::Metrics::Simple::Analysis::File';
-
-    # setup default lists for keywords and operators
-    %Perl::Metrics::Simple::Analysis::File::LOGIC_KEYWORDS = map { $_ => 1 } @Perl::Metrics::Simple::Analysis::File::DEFAULT_LOGIC_KEYWORDS;
-    %Perl::Metrics::Simple::Analysis::File::LOGIC_OPERATORS = map { $_ => 1 } @Perl::Metrics::Simple::Analysis::File::DEFAULT_LOGIC_OPERATORS;
-
-    my $complexity = $s->measure_complexity( $target );
+    my $complexity = calculate_mccabe_of_sub( $target );
 
     return $complexity;
 }
@@ -41,7 +33,7 @@ Code::Statistics::Metric::ccomp - measures the cyclomatic complexity of a target
 
 =head1 VERSION
 
-version 1.102390
+version 1.102520
 
 =head2 measure
     Returns the cyclomatic complexity of the given target.
